@@ -1,6 +1,6 @@
 /*
 ** ZABBIX
-** Copyright (C) 2000-2009 SIA Zabbix
+** Copyright (C) 2000-2010 SIA Zabbix
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -20,15 +20,16 @@
 var agt = navigator.userAgent.toLowerCase();
 var OP = (agt.indexOf("opera") != -1) && window.opera;
 var IE = (agt.indexOf("msie") != -1) && document.all && !OP;
+var IE9 = (agt.indexOf("msie 9.0") != -1) && document.all && !OP;
 var IE8 = (agt.indexOf("msie 8.0") != -1) && document.all && !OP;
-var IE7 = IE && !IE8 && document.all && !OP;
+var IE7 = (agt.indexOf("msie 7.0") != -1) && document.all && !OP;
 var IE6 = (agt.indexOf("msie 6.0") != -1) && document.all && !OP;
 var CR = (agt.indexOf("chrome") != -1);
 var SF = (agt.indexOf("safari") != -1) && !CR;
 var WK = (agt.indexOf("applewebkit") != -1);
 var KQ = (agt.indexOf("khtml") != -1) && !WK;
 var GK = (agt.indexOf("gecko") != -1) && !KQ && !WK;
-var MC = (agt.indexOf("mac") != -1)
+var MC = (agt.indexOf("mac") != -1);
 
 function checkBrowser(){
  if(OP) alert('Opera');
@@ -36,6 +37,7 @@ function checkBrowser(){
  if(IE6) alert('IE6');
  if(IE7) alert('IE7');
  if(IE8) alert('IE8');
+ if(IE9) alert('IE9');
  if(CR) alert('Chrome');
  if(SF) alert('Safari');
  if(WK) alert('Apple Webkit');
@@ -46,27 +48,35 @@ return 0;
 }
 
 function isset(key, obj){
-	if(typeof(obj[key]) != 'undefined') return true;
-return false;
+	return (typeof(obj[key]) != 'undefined');
 }
 
 function empty(obj){
 	if(is_null(obj)) return true;
-	if(obj == false) return true;
-	if((obj == 0) || (obj == '0')) return true;
-	if(is_string(obj) && (obj == '')) return true;
-	if(is_array(obj) && (obj.length == 0)) return true;
-return false;
+	if(obj === false) return true;
+//if((obj == 0) || (obj == '0')) return true;
+	if(is_string(obj) && (obj === '')) return true;
+
+	return is_array(obj) && obj.length == 0;
 }
 
 function is_null(obj){
-	if(obj==null) return true;
-return false;
+	return obj == null;
 }
 
 function is_number(obj){
 	if(isNaN(obj)) return false;
-	if(typeof(obj) === 'number') return true;
+	return typeof(obj) === 'number';
+}
+
+function is_object(obj, instance){
+	if((typeof(instance) === 'object') || (typeof(instance) === 'function')){
+		if((typeof(obj) === 'object') && (obj instanceof instance)) return true;
+	}
+	else{
+		if(typeof(obj) === 'object') return true;
+	}
+
 return false;
 }
 
@@ -81,62 +91,44 @@ function is_array(obj) {
 function SDI(msg){
 	var div_help = document.getElementById('div_help');
 
-	if((div_help == 'undefined') || empty(div_help)){
+	if((typeof(div_help) == 'undefined') || empty(div_help)){
 		var div_help = document.createElement('div');
 		var doc_body = document.getElementsByTagName('body')[0];
+		if(empty(doc_body)) return false;
+
 		doc_body.appendChild(div_help);
-		
+
 		div_help.setAttribute('id','div_help');
-		div_help.setAttribute('style','position: absolute; right: 100px; top: 10px; border: 1px red solid; width: 500px; height: 400px; background-color: white; font-size: 12px; overflow: auto; z-index: 20;');
-		
-//		new Draggable(div_help,{});
+		div_help.setAttribute('style','position: absolute; left: 10px; top: 100px; border: 1px red solid; width: 400px; height: 400px; background-color: white; font-size: 12px; overflow: auto; z-index: 20;');
+
+		//new Draggable(div_help,{});
 	}
-	
+
 	var pre = document.createElement('pre');
 	pre.appendChild(document.createTextNode(msg));
-	
+
 	div_help.appendChild(document.createTextNode("DEBUG INFO: "));
 	div_help.appendChild(document.createElement("br"));
 	div_help.appendChild(pre);
 	div_help.appendChild(document.createElement("br"));
 	div_help.appendChild(document.createElement("br"));
-	
+
 	div_help.scrollTop = div_help.scrollHeight;
 
+	return true;
 }
 
-function INFO(msg){
-	var div_info = document.getElementById('div_info');
-
-	if((div_info == 'undefined') || empty(div_info)){
-		var div_info = document.createElement('div');
-		var doc_body = document.getElementsByTagName('body')[0];
-		doc_body.appendChild(div_info);
-		
-		div_info.setAttribute('id','div_info');
-		div_info.setAttribute('style','position: absolute; left: 20px; top: 20px; height: 200px; width: 480px; border: 1px grey solid; background-color: white; font-size: 12px; overflow: auto; z-index: 20;');
-	}
-	
-	var pre = document.createElement('pre');
-	pre.appendChild(document.createTextNode(msg));
-	
-	div_info.appendChild(document.createTextNode("INFO: "));
-	div_info.appendChild(document.createElement("br"));
-	div_info.appendChild(pre);
-	div_info.appendChild(document.createElement("br"));
-	
-	div_info.scrollTop = div_info.scrollHeight;
-}
-
-function SDJ(obj){
+function SDJ(obj, name){
 	var debug = '';
 //	debug = obj.toSource();
 //	SDI(debug);
 //return null;
 
+	name = name || 'none';
 	for(var key in obj){
-		var value = obj[key];
-		debug+=key+': '+value+'  key: '+typeof(key)+'\n';
+		if(typeof(obj[key]) == name) continue;
+
+		debug+=key+': '+obj[key]+' ('+typeof(obj[key])+')'+'\n';//' key: '+typeof(key)+'\n';
 	}
 	SDI(debug);
 }
@@ -149,19 +141,19 @@ function addListener(element, eventname, expression, bubbling){
 	if(element.addEventListener){
 		element.addEventListener(eventname, expression, bubbling);
 		return true;
-	} 
+	}
 	else if(element.attachEvent){
 		element.attachEvent('on'+eventname, expression);
 		return true;
-	} 
+	}
 	else return false;
 }
 
 function add_variable(o_el, s_name, x_value, s_formname, o_document){
 	var form;
-	
+
 	if(!o_document)	o_document = document;
-	
+
 	if(s_formname){
 		if( !(form = o_document.forms[s_formname]) )
 			 throw "Missing form with name '"+s_formname+"'.";
@@ -174,24 +166,24 @@ function add_variable(o_el, s_name, x_value, s_formname, o_document){
 		if( !(form = this.form) )
 			throw "Missing form in 'this' object";
 	}
-	
+
 	var o_variable = o_document.createElement('input');
-	
+
 	if( !o_variable )	throw "Can't create element";
-	
+
 	o_variable.type = 'hidden';
 	o_variable.name = s_name;
 	o_variable.id = s_name;
 	o_variable.value = x_value;
 
 	form.appendChild(o_variable);
-	
+
 return true;
 }
 
 function cancelEvent(e){
-	if (!e) var e = window.event;	
-//SDI(e);
+	if(!e) e = window.event;
+//SDI(e.type);
 	if(e){
 		if(IE){
 			e.cancelBubble = true;
@@ -202,6 +194,7 @@ function cancelEvent(e){
 			e.preventDefault();
 		}
 	}
+
 return false;
 }
 
@@ -228,8 +221,7 @@ return true;
 
 function clearAllForm(form){
 	form = $(form);
-	var count = 0;
-	
+
 	var inputs = form.getElementsByTagName('input');
 	for(var i=0; i<inputs.length;i++){
 		var type = inputs[i].getAttribute('type');
@@ -253,7 +245,7 @@ function clearAllForm(form){
 	for(var i=0; i<selects.length;i++){
 		selects[i].selectedIndex = 0;
 	}
-	
+
 	var areas = form.getElementsByTagName('textarea');
 	for(var i=0; i<areas.length;i++){
 		areas[i].innerHTML = '';
@@ -263,16 +255,12 @@ return true;
 }
 
 function close_window(){
-	
 	window.setTimeout('window.close();', 500); /* Solve bug for Internet Explorer */
 	return false;
 }
 
 function Confirm(msg){
-	if(confirm(msg,'title'))
-		return true;
-	else
-		return false;
+	return confirm(msg, 'title');
 }
 
 function create_var(form_name, var_name, var_val, subm){
@@ -285,11 +273,11 @@ function create_var(form_name, var_name, var_val, subm){
 	if(is_null(objVar)){
 		objVar = document.createElement('input');
 		objVar.setAttribute('type',	'hidden');
-		
+
 		if(!objVar) return false;
 
 		frmForm.appendChild(objVar);
-		
+
 		objVar.setAttribute('name',	var_name);
 		objVar.setAttribute('id',	var_name);
 	}
@@ -300,7 +288,7 @@ function create_var(form_name, var_name, var_val, subm){
 	else{
 		objVar.value = var_val;
 	}
-	
+
 	if(subm)
 		frmForm.submit();
 
@@ -318,24 +306,11 @@ function deselectAll(){
 	}
 }
 
-function eventTarget(e){
-	var targ = false;
-
-	if (!e) var e = window.event;
-	if (e.target) targ = e.target;
-	else if (e.srcElement) targ = e.srcElement;
-
-// defeat Safari bug
-	if (targ.nodeType == 3) targ = targ.parentNode;
-
-return targ;
-}
-
 function getDimensions(obj, trueSide){
 	obj = $(obj);
-	
+
 	if(typeof(trueSide) == 'undefined') trueSide = false;
-	
+
 	var dim = {
 		'left':		0,
 		'top':		0,
@@ -343,7 +318,7 @@ function getDimensions(obj, trueSide){
 		'bottom':	0,
 		'width':	0,
 		'height':	0
-	}
+	};
 
 	if(!is_null(obj) && (typeof(obj.offsetParent) != 'undefined')){
 		var dim = {
@@ -353,19 +328,19 @@ function getDimensions(obj, trueSide){
 			'bottom':	parseInt(obj.style.bottom,10),
 			'width':	parseInt(obj.style.width,10),
 			'height':	parseInt(obj.style.height,10)
-		}
+		};
 
 		if(!is_number(dim.top)) dim.top = parseInt(obj.offsetTop,10);
 		if(!is_number(dim.left)) dim.left = parseInt(obj.offsetLeft,10);
 		if(!is_number(dim.width)) dim.width = parseInt(obj.offsetWidth,10);
 		if(!is_number(dim.height)) dim.height = parseInt(obj.offsetHeight,10);
-		
+
 		if(!trueSide){
 			dim.right = dim.left + dim.width;
 			dim.bottom = dim.top + dim.height;
 		}
 	}
-	
+
 return dim;
 }
 
@@ -384,6 +359,7 @@ function getPosition(obj){
 		try{
 			while(!is_null(obj.offsetParent)){
 				obj=obj.offsetParent;
+
 				pos.left += obj.offsetLeft;
 				pos.top += obj.offsetTop;
 
@@ -423,9 +399,9 @@ function get_bodywidth(){
 		w-=16;
 	}
 	else{
-		w = (w2 > w)?w2:w;
+		w = (w2 < w)?w2:w;
 	}
-
+//alert(w);
 return w;
 }
 
@@ -436,7 +412,7 @@ function get_cursor_position(e){
 	if(e.pageX || e.pageY){
 		cursor.x = e.pageX;
 		cursor.y = e.pageY;
-	} 
+	}
 	else {
 		var de = document.documentElement;
 		var b = document.body;
@@ -466,9 +442,9 @@ function get_scroll_pos(){
 	return [ scrOfX, scrOfY ];
 }
 
-function insert_in_element(element_name, text){
+function insertInElement(element_name, text, tagName){
 	if(IE)
-		var elems = $$('[name='+element_name+']');
+		var elems = $$(tagName+'[name='+element_name+']');
 	else
 		var elems = document.getElementsByName(element_name);
 
@@ -479,50 +455,26 @@ function insert_in_element(element_name, text){
 	}
 }
 
-function insert_sizeable_graph(graph_id,url){
-	if((typeof(ZBX_G_WIDTH) != 'undefined')) url += "&amp;width="+ZBX_G_WIDTH;
-
-	document.write('<img id="'+graph_id+'" src="'+url+'" alt="graph" /><br />');
-}
-
-function is_empty_form(id){
-	id = $(id);
-	var count = 0;
-
-	var inputs = id.getElementsByTagName('input');
-	for(var i=0; i<inputs.length;i++){
-		if((inputs[i].type == 'text') && (typeof(inputs[i].hidden) == 'undefined') && !empty(inputs[i].value)) return false;
-		if((inputs[i].type == 'checkbox') && (inputs[i].checked)) return false;
-	}
-
-	var selects = id.getElementsByTagName('select');
-	for(var i=0; i<selects.length;i++){
-		if((typeof(selects[i].hidden) == 'undefined') && (selects[i].selectedIndex)) return false;
-	}
-
-return true;
-}
-
 function openWinCentered(loc, winname, iwidth, iheight, params){
-		var uri = new Curl(loc);
-		loc = uri.getUrl();
+	var uri = new Curl(loc);
+	loc = uri.getUrl();
 
-		tp=Math.ceil((screen.height-iheight)/2);
-		lf=Math.ceil((screen.width-iwidth)/2);
-		if (params.length > 0){
-			params = ', ' + params;
-		}
+	var tp = Math.ceil((screen.height - iheight) / 2);
+	var lf = Math.ceil((screen.width - iwidth) / 2);
+	if (params.length > 0){
+		params = ', ' + params;
+	}
 
 	var WinObjReferer = window.open(loc,winname,"width="+iwidth+",height="+iheight+",top="+tp+",left="+lf+params);
 	WinObjReferer.focus();
 }
 
 function PopUp(url,width,height,form_name){
-	if(!width) width = 600;
-	if(!height) height = 450;
+	if(!width) width = 720;
+	if(!height) height = 480;
 	if(!form_name) form_name = 'zbx_popup';
 
-	var left = (screen.width-(width+150))/2; 
+	var left = (screen.width-(width+150))/2;
 	var top = (screen.height-(height+150))/2;
 
 	var popup = window.open(url,form_name,'width=' + width +',height=' + height + ',top='+ top +',left='+ left +
@@ -533,11 +485,42 @@ function PopUp(url,width,height,form_name){
 	return false;
 }
 
-function redirect(uri) {
-	uri = new Curl(uri);
-	var loc = uri.getUrl();
-	window.location = loc;
-	return false;
+function redirect(uri, method, needle) {
+	var method = method || 'get';
+	var url = new Curl(uri);
+
+	if(method.toLowerCase() == 'get'){
+		window.location = url.getUrl();
+	}
+	else{
+// ussless param just for easier loop
+		var action = '';
+
+		var domBody = document.getElementsByTagName('body')[0];
+		var postForm = document.createElement('form');
+		domBody.appendChild(postForm);
+		postForm.setAttribute('method', 'post');
+
+		var args = url.getArguments();
+		for(var key in args){
+			if(empty(args[key])) continue;
+			if((typeof(needle) != 'undefined') && (key.indexOf(needle) > -1)){
+				action += '&'+key+'='+args[key];
+				continue;
+			}
+			var hInput = document.createElement('input');
+			hInput.setAttribute('type', 'hidden');
+
+			postForm.appendChild(hInput);
+			hInput.setAttribute('name', key);
+			hInput.setAttribute('value', args[key]);
+		}
+
+		postForm.setAttribute('action', url.getPath()+'?'+action.substr(1));
+		postForm.submit();
+	}
+
+return false;
 }
 
 function removeListener(element, eventname, expression, bubbling){
@@ -547,11 +530,11 @@ function removeListener(element, eventname, expression, bubbling){
 	if(element.removeEventListener){
 		element.removeEventListener(eventname, expression, bubbling);
 		return true;
-	} 
+	}
 	else if(element.detachEvent){
 		element.detachEvent('on'+eventname, expression);
 		return true;
-	} 
+	}
 	else return false;
 }
 
@@ -560,12 +543,11 @@ function remove_childs(form_name,rmvbyname,tag){
 	var frmForm = document.forms[form_name];
 	for (var i=0; i < frmForm.length; i++){
 		if(frmForm.elements[i].type != 'checkbox') continue;
-		if(frmForm.elements[i].disabled == true) continue;
+		if(frmForm.elements[i].disabled) continue;
 		if(frmForm.elements[i].checked != true) continue;
 
 		var splt = frmForm.elements[i].name.split('[');
 		var name = splt[0];
-		var serviceid = splt[1];
 
 		if(rmvbyname && rmvbyname != name) continue;
 //		if(frmForm.elements[i].name != rmvbyname+'['+serviceid+'[serviceid]') continue;
@@ -580,10 +562,10 @@ function remove_element(elmnt,tag){
 	if(!is_null(elmnt)){
 		if(('undefined' != typeof(elmnt.nodeName)) && (elmnt.nodeName.toLowerCase() == tag.toLowerCase())){
 			elmnt.parentNode.removeChild(elmnt);
-		} 
+		}
 		else if(elmnt.nodeType == 9){
 			return false;
-		} 
+		}
 		else {
 			remove_element(elmnt.parentNode,tag);
 		}
@@ -592,14 +574,13 @@ return true;
 }
 
 function ShowHide(obj,style){
-	if(typeof(style) == 'undefined') var style = 'inline';
+	if(typeof(style) == 'undefined') style = 'inline';
 
 	if(is_string(obj))
 		obj = document.getElementById(obj);
 
 	if(!obj){
 		throw 'ShowHide(): Object not found.';
-		return false;
 	}
 
 	if(obj.style.display != 'none'){
@@ -613,33 +594,30 @@ function ShowHide(obj,style){
 }
 
 function showHideByName(name, style){
-	if(typeof(style) == 'undefined') var style = 'none';
+	if(typeof(style) == 'undefined') style = 'none';
 
 	var objs = $$('[name='+name+']');
 
 	if(empty(objs)){
 		throw 'ShowHide(): Object not found.';
-		return false;
 	}
-	
+
 	for(var i=0; i<objs.length; i++){
 		var obj = objs[i];
 		obj.style.display = style;
 	}
-
 }
 
 function showHideEffect(obj, eff, time, cb_afterFinish){
 	obj = $(obj);
 	if(!obj){
 		throw 'showHideEffect(): Object not found.';
-		return false;
 	}
 
 	if(typeof(Effect) == 'undefined'){
 		eff = 'none';
 	}
-	
+
 	if(typeof(cb_afterFinish) == 'undefined'){
 		cb_afterFinish = function(){};
 	}
@@ -676,26 +654,42 @@ function switchElementsClass(obj,class1,class2){
 	obj = $(obj);
 	if(!obj) return false;
 
-	if(obj.className == class1){
-		obj.className = class2;
-		return class2;
+	var result = false;
+	if(obj.hasClassName(class1)){
+		obj.removeClassName(class1);
+		obj.className = class2 + ' ' + obj.className;
+		result = class2;
+	}
+	else if(obj.hasClassName(class2)){
+		obj.removeClassName(class2);
+		obj.className =  class1 + ' ' + obj.className;
+		result = class1;
 	}
 	else{
-		obj.className = class1;
-		return class1;
+		obj.className = class1 + ' ' + obj.className;
+		result = class1;
 	}
-return false;
+
+	if(IE6){
+		obj.style.filter = '';
+		obj.style.backgroundImage = '';
+		ie6pngfix.run();
+	}
+
+return result;
 }
 
-
+function zbx_throw(msg){
+	throw(msg);
+}
 /************************************************************************************/
 /*									Pages stuff										*/
 /************************************************************************************/
 function openPage(start){
-	var lnk = new Curl(location.href); 
+	var lnk = new Curl(location.href);
 	lnk.setArgument('start', start);
 	location.href = lnk.getUrl();
-	
+
 return false;
 }
 
@@ -704,52 +698,7 @@ function ScaleChartToParenElement(obj_name){
 
 	if(obj.length <= 0) throw "Can't find objects with name [" + obj_name +"]";
 
-	for(i = obj.length-1; i>=0; i--){
+	for(var i = obj.length-1; i>=0; i--){
 		obj[i].src += "&width=" + (obj[i].parentNode.offsetWidth - obj[i].parentNode.offsetLeft - 10);
 	}
 }
-
-
-/************************************************************************************/
-/*										IE 6 FIXES 									*/
-/************************************************************************************/
-
-function hidePopupDiv(iFrameID){
-	if(!IE6) return;
-
-	$(iFrameID).hide();
-	$(iFrameID).remove();
-}
-
-function showPopupDiv(divID,iFrameID){
-	if(!IE6) return;
-
-	var iFrame = $(iFrameID);
-	var divPopup = $(divID);
-
-	if(is_null(iFrame)){
-		var iFrame = document.createElement('iframe');
-		document.body.appendChild(iFrame);
-		
-		//Match IFrame position with divPopup
-		iFrame.setAttribute('id',iFrameID);
-		iFrame.style.position='absolute';
-	}
-	
-	if(divPopup.style.display == 'none'){
-		iFrame.style.display = 'none';
-		return;
-	}
-
-//Increase default zIndex of div by 1, so that DIV appears before IFrame
-	divPopup.style.zIndex=divPopup.style.zIndex+1;
-//	iFrame.style.zIndex = 1;
-
-
-	var divCumOff = $(divID).cumulativeOffset();
-	iFrame.style.display = 'block';
-	iFrame.style.left = divCumOff.left + 'px';
-	iFrame.style.top = divCumOff.top + 'px';
-	iFrame.style.width = divPopup.offsetWidth + 'px';
-	iFrame.style.height = divPopup.offsetHeight + 'px';
-}
\ No newline at end of file
