@@ -19,11 +19,11 @@
 **/
 ?>
 <?php
-	require_once('include/config.inc.php');
+require_once('include/config.inc.php');
 
-	$page['title'] = "S_IT_NOTIFICATIONS";
-	$page['file'] = 'report4.php';
-	$page['hist_arg'] = array('media_type','period','year');
+$page['title'] = "S_IT_NOTIFICATIONS";
+$page['file'] = 'report4.php';
+$page['hist_arg'] = array('media_type','period','year');
 
 include_once('include/page_header.php');
 
@@ -89,13 +89,15 @@ include_once('include/page_header.php');
 	$_REQUEST['period']	= $period;
 	$_REQUEST['media_type']	= $media_type;
 
+	$css = getUserTheme($USER_DETAILS);
+	$vTextColor = ($css == 'css_od.css')?'&color=white':'';
 
-        $table = new CTableInfo();
+    $table = new CTableInfo();
 
 	$header = array();
 	$db_users = DBselect('select * from users where '.DBin_node('userid').' order by alias,userid');
 	while($user_data = DBfetch($db_users)){
-		array_push($header, new CImg('vtext.php?text='.$user_data['alias']));
+		array_push($header, new CImg('vtext.php?text='.$user_data['alias'].$vTextColor));
 		$users[$user_data['userid']] = $user_data['alias'];
 	}
 
@@ -117,24 +119,24 @@ include_once('include/page_header.php');
 			$to	= date('Y');
 			array_unshift($header, new CCol(S_YEAR,'center'));
 			function get_time($y)	{	return mktime(0,0,0,1,1,$y);		}
-			function format_time($t){	return date('Y', $t);			}
-			function format_time2($t){	return null; };
+			function format_time($t){	return zbx_date2str(S_REPORT4_ANNUALLY_DATE_FORMAT, $t);}
+			function format_time2($t){	return null; }
 			break;
 		case 'monthly':
 			$from	= 1;
 			$to	= 12;
 			array_unshift($header, new CCol(S_MONTH,'center'));
 			function get_time($m)	{	global $year;	return mktime(0,0,0,$m,1,$year);	}
-			function format_time($t){	return date('M Y',$t);			}
-			function format_time2($t){	return null; };
+			function format_time($t){	return zbx_date2str(S_REPORT4_MONTHLY_DATE_FORMAT,$t);	}
+			function format_time2($t){	return null; }
 			break;
 		case 'dayly':
 			$from	= 1;
 			$to	= 365;
 			array_unshift($header, new CCol(S_DAY,'center'));
 			function get_time($d)	{	global $year;	return mktime(0,0,0,1,$d,$year);	}
-			function format_time($t){	return date('d M Y',$t);		}
-			function format_time2($t){	return null; };
+			function format_time($t){	return zbx_date2str(S_REPORT4_DAILY_DATE_FORMAT,$t);	}
+			function format_time2($t){	return null; }
 			break;
 		case 'weekly':
 		default:
@@ -150,14 +152,13 @@ include_once('include/page_header.php');
 
 				return ($time + ($w*7 - $wd)*24*3600);
 			}
-			function format_time($t){	return date('d M Y H:i',$t);	}
-			function format_time2($t){	return format_time($t); };
+			function format_time($t){	return zbx_date2str(S_REPORT4_WEEKLY_DATE_FORMAT,$t);	}
+			function format_time2($t){	return format_time($t); }
 			break;
 
 	}
 
-	$table->SetHeader($header,'vertical_header');
-
+	$table->setHeader($header,'vertical_header');
 	for($t = $from; $t <= $to; $t++){
 		if(($start = get_time($t)) > time())
 			break;
@@ -166,26 +167,46 @@ include_once('include/page_header.php');
 			$end = time();
 
 		$table_row = array(format_time($start),format_time2($end));
-		foreach($users as $userid => $alias){
-			$all = 0;
-			$cnt_by_type = array();
 
-			foreach($media_types as $mediatypeid => $description){
-				$sql = 'SELECT count(*) as cnt '.
-						' FROM alerts a '.
-						' WHERE a.userid='.$userid.
-							' AND a.mediatypeid='.$mediatypeid.
-							' AND a.clock>'.$start.
-							' AND a.clock<'.$end;
-				$cnt_data = DBfetch(DBselect($sql));
-				if(!$cnt_data)	$cnt_data = 0;
-				else		$cnt_data = $cnt_data['cnt'];
+		//getting all alerts in this period of time
+		$options = array(
+			'output'=> array('mediatypeid', 'userid'),
+			'time_from'=>$start,
+			'time_till'=>$end
+		);
 
-				array_push($cnt_by_type, $cnt_data);
-				$all += $cnt_data;
-			}
-			array_push($table_row,array($all, ($media_type == 0 ? SPACE.'('.implode('/',$cnt_by_type).')' : '' )));
+		//if we must get only specific media type, no need to select the other ones
+		if ($media_type>0){
+			$options['mediatypeids'] = $media_type;
 		}
+
+		//getting data throung API
+		$alert_info = CAlert::get($options);
+
+		//counting alert count for each user and media type
+		$summary = array();
+		foreach($users as $userid => $alias){
+			$summary[$userid] = array();
+			$summary[$userid]['total'] = 0;
+			$summary[$userid]['medias'] = array('1'=>0, '2'=>0, '3'=>0, '4'=>0);
+		}
+		
+		foreach($alert_info as $ai){
+			if( !isset($summary[$ai['userid']]) ) continue;
+
+			$summary[$ai['userid']]['total']++;
+			if (isset($summary[$ai['userid']]['medias'][$ai['mediatypeid']])) {
+				$summary[$ai['userid']]['medias'][$ai['mediatypeid']]++;
+			}
+			else {
+				$summary[$ai['userid']]['medias'][$ai['mediatypeid']] = 1;
+			}
+		}
+		
+		foreach($summary as $s){
+			array_push($table_row, array($s['total'], ($media_type == 0 ? SPACE.'('.implode('/',$s['medias']).')' : '' )));
+		}
+
 		$table->addRow($table_row);
 	}
 	$table->show();
@@ -196,6 +217,9 @@ include_once('include/page_header.php');
 		$table->Show();
 	}
 
+?>
+<?php
+
+include_once('include/page_footer.php');
 
-include_once 'include/page_footer.php';
 ?>
\ No newline at end of file
