@@ -1,7 +1,7 @@
 <?php
 /*
 ** ZABBIX
-** Copyright (C) 2000-2009 SIA Zabbix
+** Copyright (C) 2000-2010 SIA Zabbix
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ require_once('include/forms.inc.php');
 if(isset($_REQUEST['go']) && ($_REQUEST['go'] == 'export') && isset($_REQUEST['maps'])){
 	$EXPORT_DATA = true;
 
-	$page['type'] = $page['type'] = detect_page_type(PAGE_TYPE_XML);
+	$page['type'] = detect_page_type(PAGE_TYPE_XML);
 	$page['file'] = 'zbx_maps_export.xml';
 
 	require_once('include/export.inc.php');
@@ -52,21 +52,20 @@ include_once('include/page_header.php');
 		'width'=>			array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,65535),	'isset({save})'),
 		'height'=>			array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,65535),	'isset({save})'),
 		'backgroundid'=>	array(T_ZBX_INT, O_OPT,	 NULL,	DB_ID,				'isset({save})'),
-		'expproblem'=>		array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,1),		null),
+		'expandproblem'=>	array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,1),		null),
+		'markelements'=>	array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,1),		null),
+		'show_unack'=>	        array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,2),		null),
 		'highlight'=>		array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,1),		null),
 		'label_type'=>		array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,4),		'isset({save})'),
 		'label_location'=>	array(T_ZBX_INT, O_OPT,	 NULL,	BETWEEN(0,3),		'isset({save})'),
-
 // Actions
 		'save'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
 		'delete'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
 		'cancel'=>			array(T_ZBX_STR, O_OPT, P_SYS, NULL,	NULL),
 		'go'=>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, NULL, NULL),
-
 // Form
 		'form'=>			array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
 		'form_refresh'=>	array(T_ZBX_INT, O_OPT,	NULL,	NULL,	NULL),
-
 // Import
 		'rules' =>			array(T_ZBX_STR, O_OPT,	null,	DB_ID,		null),
 		'import' =>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL)
@@ -81,7 +80,6 @@ include_once('include/page_header.php');
 			'editable' => 1,
 			'extendoutput' => 1,
 		);
-
 		$maps = CMap::get($options);
 
 		if(empty($maps)) access_deny();
@@ -92,7 +90,6 @@ include_once('include/page_header.php');
 // EXPORT ///////////////////////////////////
 
 	if($EXPORT_DATA){
-// SELECT MAPS
 		$maps = get_request('maps', array());
 
 		$options = array(
@@ -101,12 +98,21 @@ include_once('include/page_header.php');
 			'select_links' => API_OUTPUT_EXTEND,
 			'output' => API_OUTPUT_EXTEND
 		);
-
 		$sysmaps = CMap::get($options);
 
-		prepareMapExport($sysmaps);
+		$options = array(
+			'sysmapids' => zbx_objectValues($sysmaps, 'sysmapid'),
+			'output' => API_OUTPUT_EXTEND,
+			'select_image' => 1
+		);
+		$images = CImage::get($options);
 
-		$xml = zbxXML::arrayToXML($sysmaps, 'sysmaps');
+
+		prepareMapExport($sysmaps);
+		$images = prepareImageExport($images);
+		$sysmaps = array('images' => $images, 'sysmaps' => $sysmaps);
+
+		$xml = zbxXML::arrayToXML($sysmaps);
 		print($xml);
 
 		exit();
@@ -115,8 +121,9 @@ include_once('include/page_header.php');
 // IMPORT ///////////////////////////////////
 	$rules = get_request('rules', array());
 	if(!isset($_REQUEST['form_refresh'])){
-		foreach(array('map') as $key){
-			$rules[$key]['exist'] = 1;
+		foreach(array('maps', 'icons', 'background') as $key){
+			if($key == 'maps')
+				$rules[$key]['exist'] = 1;
 			$rules[$key]['missed'] = 1;
 		}
 	}
@@ -136,24 +143,22 @@ include_once('include/page_header.php');
 <?php
 	$_REQUEST['go'] = get_request('go', 'none');
 
-	if(isset($_REQUEST["save"])){
-		if(isset($_REQUEST["sysmapid"])){
+	if(isset($_REQUEST['save'])){
+		if(isset($_REQUEST['sysmapid'])){
 // TODO check permission by new value.
-			$_REQUEST['highlight'] = get_request('highlight', 0);
-			$_REQUEST['expproblem'] = get_request('expproblem', 0);
-
 			$map = array(
-					'sysmapid' => $_REQUEST['sysmapid'],
-					'name' => $_REQUEST['name'],
-					'width' => $_REQUEST['width'],
-					'height' => $_REQUEST['height'],
-					'backgroundid' => $_REQUEST['backgroundid'],
-					'highlight' => $_REQUEST['highlight'],
-					'label_type' => $_REQUEST['label_type'],
-					'label_location' => $_REQUEST['label_location']
-				);
-
-			if($_REQUEST['expproblem'] == 0) $map['highlight']+=2;
+				'sysmapid' => $_REQUEST['sysmapid'],
+				'name' => $_REQUEST['name'],
+				'width' => $_REQUEST['width'],
+				'height' => $_REQUEST['height'],
+				'backgroundid' => $_REQUEST['backgroundid'],
+				'highlight' => get_request('highlight', 0),
+				'markelements' => get_request('markelements', 0),
+				'expandproblem' => get_request('expandproblem', 0),
+				'label_type' => $_REQUEST['label_type'],
+				'label_location' => $_REQUEST['label_location'],
+				'show_unack' => get_request('show_unack', 0),
+			);
 
 			DBstart();
 			$result = CMap::update($map);
@@ -166,20 +171,18 @@ include_once('include/page_header.php');
 			if(!count(get_accessible_nodes_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY)))
 				access_deny();
 
-			$_REQUEST['highlight'] = get_request('highlight', 0);
-			$_REQUEST['expproblem'] = get_request('expproblem', 0);
-			
 			$map = array(
-					'name' => $_REQUEST['name'],
-					'width' => $_REQUEST['width'],
-					'height' => $_REQUEST['height'],
-					'backgroundid' => $_REQUEST['backgroundid'],
-					'highlight' => $_REQUEST['highlight'],
-					'label_type' => $_REQUEST['label_type'],
-					'label_location' => $_REQUEST['label_location']
-				);
-
-			if($_REQUEST['expproblem'] == 0) $map['highlight']+=2;
+				'name' => $_REQUEST['name'],
+				'width' => $_REQUEST['width'],
+				'height' => $_REQUEST['height'],
+				'backgroundid' => $_REQUEST['backgroundid'],
+				'highlight' => get_request('highlight', 0),
+				'markelements' => get_request('markelements', 0),
+				'expandproblem' => get_request('expandproblem', 0),
+				'label_type' => $_REQUEST['label_type'],
+				'label_location' => $_REQUEST['label_location'],
+				'show_unack' => get_request('show_unack', 0),
+			);
 
 			DBstart();
 			$result = CMap::create($map);
@@ -189,37 +192,28 @@ include_once('include/page_header.php');
 			show_messages($result,S_MAP_ADDED,S_CANNOT_ADD_MAP);
 		}
 		if($result){
-			unset($_REQUEST["form"]);
+			unset($_REQUEST['form']);
 		}
 	}
-	else if(isset($_REQUEST["delete"])&&isset($_REQUEST["sysmapid"])){
-		$maps = zbx_toObject($_REQUEST["sysmapid"], 'sysmapid');
-
-		DBstart();
-		$result = CMap::delete($maps);
-		$result = DBend($result);
-
-		add_audit_if($result,AUDIT_ACTION_DELETE,AUDIT_RESOURCE_MAP,'Name ['.$sysmap['name'].']');
-		show_messages($result, S_MAP_DELETED, S_CANNOT_DELETE_MAP);
-		if($result){
-			unset($_REQUEST["form"]);
+	else if((isset($_REQUEST['delete'])&&isset($_REQUEST['sysmapid'])) || ($_REQUEST['go'] == 'delete')){
+		$sysmapids = get_request('maps', array());
+		if(isset($_REQUEST['sysmapid'])){
+			$sysmapids[] = $_REQUEST['sysmapid'];
 		}
-	}
-	else if($_REQUEST['go'] == 'delete'){
-		$go_result = true;
-		$maps = get_request('maps', array());
 
-		$maps = zbx_toObject($maps, 'sysmapid');
+		$maps = CMap::get(array('sysmapids' => $sysmapids, 'output' => API_OUTPUT_EXTEND, 'editable => 1'));
+		$go_result = CMap::delete($sysmapids);
 
-		DBstart();
-		$result = CMap::delete($maps);
-		$go_result = DBend($result);
-		
-
-		if($go_result){
-			unset($_REQUEST["form"]);
-		}
 		show_messages($go_result, S_MAP_DELETED, S_CANNOT_DELETE_MAP);
+		if($go_result){
+			unset($_REQUEST['form']);
+			foreach($maps as $map){
+				add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_MAP,
+					$map['sysmapid'],
+					$map['name'],
+					null,null,null);
+			}
+		}
 	}
 
 	if(($_REQUEST['go'] != 'none') && isset($go_result) && $go_result){
@@ -230,26 +224,21 @@ include_once('include/page_header.php');
 
 ?>
 <?php
-	$form = new CForm();
-	$form->setMethod('get');
-
+	$form = new CForm(null, 'get');
 	$form->addItem(new CButton('form', S_CREATE_MAP));
 	$form->addItem(new CButton('form', S_IMPORT_MAP));
 
 	$map_wdgt = new CWidget();
 	$map_wdgt->addPageHeader(S_CONFIGURATION_OF_NETWORK_MAPS, $form);
-?>
-<?php
-//	COpt::savesqlrequest(0,'/////////////////////////////////////////////////////////////////////////////////////////////////////////');
+
+
 	if(isset($_REQUEST['form'])){
 		if($_REQUEST['form'] == S_IMPORT_MAP)
 			$map_wdgt->addItem(import_map_form($rules));
 		else if(($_REQUEST['form'] == S_CREATE_MAP) || ($_REQUEST['form'] == 'update'))
 			$map_wdgt->addItem(insert_map_form());
-			
 	}
 	else{
-		
 		$form = new CForm();
 		$form->setName('frm_maps');
 
@@ -298,7 +287,6 @@ include_once('include/page_header.php');
 // goBox
 		$goBox = new CComboBox('go');
 		$goBox->addItem('export', S_EXPORT_SELECTED);
-
 		$goOption = new CComboItem('delete', S_DELETE_SELECTED);
 		$goOption->setAttribute('confirm',S_DELETE_SELECTED_MAPS_Q);
 
@@ -308,29 +296,19 @@ include_once('include/page_header.php');
 		$goButton = new CButton('goButton',S_GO);
 		$goButton->setAttribute('id','goButton');
 
-		$jsLocale = array(
-			'S_CLOSE',
-			'S_NO_ELEMENTS_SELECTED'
-		);
-
-		zbx_addJSLocale($jsLocale);
-
 		zbx_add_post_js('chkbxRange.pageGoName = "maps";');
 
 		$footer = get_table_header(array($goBox, $goButton));
-//------
-
-// PAGING FOOTER
 		$table = array($paging, $table, $paging, $footer);
-//---------
 
 		$form->addItem($table);
-
 		$map_wdgt->addItem($form);
 	}
-	
-	$map_wdgt->show();
 
+	$map_wdgt->show();
+?>
+<?php
 
 include_once('include/page_footer.php');
-?>
\ No newline at end of file
+
+?>
