@@ -28,7 +28,7 @@
 
 	$page['file'] = 'tr_status.php';
 	$page['title'] = 'S_STATUS_OF_TRIGGERS';
-	$page['scripts'] = array('scriptaculous.js?load=effects');
+	$page['scripts'] = array('effects.js');
 	$page['hist_arg'] = array('groupid', 'hostid');
 	$page['scripts'] = array('class.cswitcher.js');
 
@@ -37,47 +37,6 @@
 ?>
 <?php
 if($page['type'] == PAGE_TYPE_HTML){
-	$tr_hash = calc_trigger_hash();
-
-	$triggers_hash = get_cookie('zbx_triggers_hash', '0,0');
-
-	$new = explode(',', $tr_hash);
-	$old = explode(',', $triggers_hash);
-
-	zbx_set_post_cookie('zbx_triggers_hash', $tr_hash, time()+1800);
-
-	$triggers_hash = get_cookie('zbx_triggers_hash', '0,0');
-
-	$new = explode(',', $tr_hash);
-	$old = explode(',', $triggers_hash);
-
-	if( $old[1] != $new[1] ){
-		if( $new[0] < $old[0] )	// Number of trigger decreased
-			$status = 'off';
-		else			// Number of trigger increased
-			$status = 'on';
-
-		$files_apdx = array(
-			5 => 'disaster',
-			4 => 'high',
-			3 => 'average',
-			2 => 'warning',
-			1 => 'information',
-			0 => 'not_classified');
-
-		$prior_dif = $new[0] - $old[0];
-
-		krsort($files_apdx);
-		foreach($files_apdx as $priority => $apdx){
-			if(round($prior_dif / pow(100, $priority)) != 0){
-				$audio = 'audio/trigger_'.$status.'_'.$apdx.'.wav';
-				break;
-			}
-		}
-
-		if(!isset($audio) || !file_exists($audio))
-			$audio = 'audio/trigger_'.$status.'.wav';
-	}
 	define('ZBX_PAGE_DO_REFRESH', 1);
 }
 
@@ -93,26 +52,26 @@ include_once('include/page_header.php');
 		'fullscreen'=>			array(T_ZBX_INT, O_OPT,		P_SYS,	IN('0,1'),				null),
 		'btnSelect'=>			array(T_ZBX_STR, O_OPT,  	null,  	null, 					null),
 // filter
-		'filter_rst'=>			array(T_ZBX_STR, O_OPT,		P_SYS,	null,	NULL),
-		'filter_set'=>			array(T_ZBX_STR, O_OPT,		P_SYS,	null,	NULL),
+		'filter_rst'=>			array(T_ZBX_STR, O_OPT,		P_ACT,	null,	NULL),
+		'filter_set'=>			array(T_ZBX_STR, O_OPT,		P_ACT,	null,	NULL),
 		'show_triggers'=>		array(T_ZBX_INT, O_OPT,  	null, 	null, 	null),
 		'show_events'=>			array(T_ZBX_INT, O_OPT,		P_SYS,	null,	null),
+		'ack_status'=>			array(T_ZBX_INT, O_OPT,		P_SYS,	null,	null),
 		'show_severity'=>		array(T_ZBX_INT, O_OPT,		P_SYS,	null,	null),
 		'show_details'=>		array(T_ZBX_INT, O_OPT,  	null,	null, 	null),
+		'status_change_days'=>	array(T_ZBX_INT, O_OPT,  	null,	null, 	null),
+		'status_change'=>		array(T_ZBX_INT, O_OPT,  	null,	null, 	null),
 		'txt_select'=>			array(T_ZBX_STR, O_OPT,  	null,	null, 	null),
 //ajax
-		'favobj'=>		array(T_ZBX_STR, O_OPT, P_ACT,	NULL,			'isset({favid})'),
-		'favid'=>		array(T_ZBX_STR, O_OPT, P_ACT,  NOT_EMPTY,		NULL),
+		'favobj'=>		array(T_ZBX_STR, O_OPT, P_ACT,	NULL,			NULL),
+		'favref'=>		array(T_ZBX_STR, O_OPT, P_ACT,  NOT_EMPTY,		'isset({favobj})'),
 		'state'=>		array(T_ZBX_INT, O_OPT, P_ACT,  NOT_EMPTY,		'isset({favobj})'),
 	);
 
 	check_fields($fields);
 
 	if(isset($_REQUEST['favobj'])){
-		if(str_in_array($_REQUEST['favobj'] ,array('sound'))){
-			CProfile::update('web.tr_status.mute',$_REQUEST['state'], PROFILE_TYPE_INT);
-		}
-		else if('filter' == $_REQUEST['favobj']){
+		if('filter' == $_REQUEST['favobj']){
 			CProfile::update('web.tr_status.filter.state',$_REQUEST['state'], PROFILE_TYPE_INT);
 		}
 	}
@@ -125,107 +84,101 @@ include_once('include/page_header.php');
 
 	$config = select_config();
 
-	$options = array('allow_all_hosts','monitored_hosts','with_monitored_triggers');
-	$params = array();
-	foreach($options as  $option) $params[$option] = 1;
-	$PAGE_GROUPS = get_viewed_groups(PERM_READ_ONLY, $params);
-	$PAGE_HOSTS = get_viewed_hosts(PERM_READ_ONLY, $PAGE_GROUPS['selected'], $params);
-	validate_group_with_host($PAGE_GROUPS,$PAGE_HOSTS);
+	$options = array(
+		'groups' => array(
+			'monitored_hosts' => 1,
+			'with_monitored_triggers' => 1,
+		),
+		'hosts' => array(
+			'monitored_hosts' => 1,
+			'with_monitored_triggers' => 1,
+		),
+		'hostid' => get_request('hostid', null),
+		'groupid' => get_request('groupid', null),
+	);
+	$pageFilter = new CPageFilter($options);
+	$_REQUEST['groupid'] = $pageFilter->groupid;
+	$_REQUEST['hostid'] = $pageFilter->hostid;
 
-	// $_REQUEST['groupid'] = get_request('groupid', 0);
-	// $_REQUEST['hostid'] = get_request('hostid', 0);
 
 /* FILTER */
 	if(isset($_REQUEST['filter_rst'])){
 		$_REQUEST['show_details'] =	0;
 		$_REQUEST['show_triggers'] = TRIGGERS_OPTION_ONLYTRUE;
 		$_REQUEST['show_events'] = EVENTS_OPTION_NOEVENT;
+		$_REQUEST['ack_status'] = ZBX_ACK_STS_ANY;
 		$_REQUEST['show_severity'] = -1;
 		$_REQUEST['txt_select'] = '';
-	}
-
-	if(isset($_REQUEST['filter_set'])){
-		$_REQUEST['show_details'] = get_request('show_details',	0);
+		$_REQUEST['status_change'] = 0;
+		$_REQUEST['status_change_days'] = 14;
 	}
 	else{
-		$_REQUEST['show_details'] = get_request('show_details',	CProfile::get('web.tr_status.filter.show_details', 0));
-	}
+		if(isset($_REQUEST['filter_set'])){
+			$_REQUEST['show_details'] = get_request('show_details', 0);
+			$_REQUEST['status_change'] = get_request('status_change', 0);
+			$_REQUEST['show_triggers'] = get_request('show_triggers', TRIGGERS_OPTION_ONLYTRUE);
+		}
+		else{
+			$_REQUEST['show_details'] = get_request('show_details',	CProfile::get('web.tr_status.filter.show_details', 0));
+			$_REQUEST['status_change'] = get_request('status_change', CProfile::get('web.tr_status.filter.status_change', 0));
+			$_REQUEST['show_triggers'] = TRIGGERS_OPTION_ONLYTRUE;
+		}
+		$_REQUEST['show_events'] = get_request('show_events', CProfile::get('web.tr_status.filter.show_events', EVENTS_OPTION_NOEVENT));
+		$_REQUEST['ack_status'] = get_request('ack_status', CProfile::get('web.tr_status.filter.ack_status', ZBX_ACK_STS_ANY));
+		$_REQUEST['show_severity'] = get_request('show_severity', CProfile::get('web.tr_status.filter.show_severity', -1));
+		$_REQUEST['status_change_days'] = get_request('status_change_days', CProfile::get('web.tr_status.filter.status_change_days', 14));
+		$_REQUEST['txt_select'] = get_request('txt_select', CProfile::get('web.tr_status.filter.txt_select', ''));
 
-	$_REQUEST['show_triggers'] = get_request('show_triggers', CProfile::get('web.tr_status.filter.show_triggers', TRIGGERS_OPTION_ONLYTRUE));
-	$_REQUEST['show_events'] = get_request('show_events', CProfile::get('web.tr_status.filter.show_events', EVENTS_OPTION_NOEVENT));
-	$_REQUEST['show_severity'] = get_request('show_severity', CProfile::get('web.tr_status.filter.show_severity', -1));
-	$_REQUEST['txt_select'] = get_request('txt_select', CProfile::get('web.tr_status.filter.txt_select', ''));
+		if(EVENT_ACK_DISABLED == $config['event_ack_enable']){
+			if(!str_in_array($_REQUEST['show_events'],array(EVENTS_OPTION_NOEVENT,EVENTS_OPTION_ALL))){
+				$_REQUEST['show_events'] = EVENTS_OPTION_NOEVENT;
+			}
+			$_REQUEST['ack_status'] = ZBX_ACK_STS_ANY;
+		}
+	}
 
 	if(get_request('show_events') != CProfile::get('web.tr_status.filter.show_events')){
 		$url = new CUrl();
 		$path = $url->getPath();
 		insert_js('cookie.eraseArray("'.$path.'")');
-	}	
-	
-	if((EVENT_ACK_DISABLED == $config['event_ack_enable']) && !str_in_array($_REQUEST['show_events'],array(EVENTS_OPTION_NOEVENT,EVENTS_OPTION_ALL))){
-		$_REQUEST['show_events'] = EVENTS_OPTION_NOEVENT;
 	}
 //--
 
-	$_REQUEST['show_triggers'] = (($_REQUEST['groupid'] == 0) && ($_REQUEST['hostid'] == 0) && ($_REQUEST['show_triggers'] == TRIGGERS_OPTION_ALL))
-		? TRIGGERS_OPTION_ONLYTRUE : $_REQUEST['show_triggers'];
 	if(isset($_REQUEST['filter_set']) || isset($_REQUEST['filter_rst'])){
 		CProfile::update('web.tr_status.filter.show_details', $_REQUEST['show_details'], PROFILE_TYPE_INT);
-		CProfile::update('web.tr_status.filter.show_triggers', $_REQUEST['show_triggers'], PROFILE_TYPE_INT);
 		CProfile::update('web.tr_status.filter.show_events', $_REQUEST['show_events'], PROFILE_TYPE_INT);
+		CProfile::update('web.tr_status.filter.ack_status', $_REQUEST['ack_status'], PROFILE_TYPE_INT);
 		CProfile::update('web.tr_status.filter.show_severity', $_REQUEST['show_severity'], PROFILE_TYPE_INT);
 		CProfile::update('web.tr_status.filter.txt_select', $_REQUEST['txt_select'], PROFILE_TYPE_STR);
+		CProfile::update('web.tr_status.filter.status_change', $_REQUEST['status_change'], PROFILE_TYPE_INT);
+		CProfile::update('web.tr_status.filter.status_change_days', $_REQUEST['status_change_days'], PROFILE_TYPE_INT);
 	}
 
 	$show_triggers = $_REQUEST['show_triggers'];
 	$show_events = $_REQUEST['show_events'];
 	$show_severity = $_REQUEST['show_severity'];
+	$ack_status = $_REQUEST['ack_status'];
 // --------------
 	validate_sort_and_sortorder('lastchange', ZBX_SORT_DOWN);
 
-
 	$mute = CProfile::get('web.tr_status.mute', 0);
 	if(isset($audio) && !$mute){
 		play_sound($audio);
 	}
 ?>
 <?php
-
-
 	$trigg_wdgt = new CWidget();
 
-	$r_form = new CForm();
-	$r_form->setMethod('get');
+	$r_form = new CForm(null, 'get');
+	$r_form->addItem(array(S_GROUP . SPACE, $pageFilter->getGroupsCB(true)));
+	$r_form->addItem(array(SPACE . S_HOST . SPACE, $pageFilter->getHostsCB(true)));
+	$r_form->addVar('fullscreen', $_REQUEST['fullscreen']);
 
-	$cmbGroups = new CComboBox('groupid',$PAGE_GROUPS['selected'],'javascript: submit();');
-	$cmbHosts = new CComboBox('hostid',$PAGE_HOSTS['selected'],'javascript: submit();');
-
-	foreach($PAGE_GROUPS['groups'] as $groupid => $name){
-		$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid, null, ': ').$name);
-	}
-	foreach($PAGE_HOSTS['hosts'] as $hostid => $name){
-		$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid, null, ': ').$name);
-	}
-
-
-	$r_form->addItem(array(S_GROUP.SPACE,$cmbGroups));
-	$r_form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));
-	$r_form->addVar('fullscreen',$_REQUEST['fullscreen']);
-
-	$url = 'tr_status.php'.($_REQUEST['fullscreen'] ? '' : '?fullscreen=1');
-	$fs_icon = new CDiv(SPACE,'fullscreen');
-	$fs_icon->setAttribute('title',$_REQUEST['fullscreen']?S_NORMAL.' '.S_VIEW:S_FULLSCREEN);
-	$fs_icon->addAction('onclick',new CJSscript("javascript: document.location = '".$url."';"));
-
-	$mute_icon = new CDiv(SPACE,$mute?'iconmute':'iconsound');
-	$mute_icon->setAttribute('title',S_SOUND.' '.S_ON.'/'.S_OFF);
-	$mute_icon->addAction('onclick',new CJSscript("javascript: switch_mute(this);"));
-
-//	show_table_header(S_STATUS_OF_TRIGGERS_BIG,array($mute_icon,$fs_icon));
-	$trigg_wdgt->addPageHeader(S_STATUS_OF_TRIGGERS_BIG, array($mute_icon, $fs_icon));
+	$fs_icon = get_icon('fullscreen', array('fullscreen' => $_REQUEST['fullscreen']));
+	$trigg_wdgt->addPageHeader(S_STATUS_OF_TRIGGERS_BIG . ' [' . date(S_DATE_FORMAT_YMDHMS) . ']', array($fs_icon));
 
 	$numrows = new CDiv();
-	$numrows->setAttribute('name','numrows');
+	$numrows->setAttribute('name', 'numrows');
 	$trigg_wdgt->addHeader(S_TRIGGERS_BIG, $r_form);
 	$trigg_wdgt->addHeader($numrows);
 
@@ -241,52 +194,58 @@ include_once('include/page_header.php');
 	$filterForm->addVar('hostid', $_REQUEST['hostid']);
 
 	$tr_select = new CComboBox('show_triggers', $show_triggers);
-	if(($_REQUEST['hostid'] == 0) && ($_REQUEST['groupid'] == 0) && TRIGGERS_OPTION_ALL){
-		$tr_select->addItem(TRIGGERS_OPTION_ALL, S_SHOW_ALL, false, false);
-	}
-	else if(TRIGGERS_OPTION_ALL){
-		$tr_select->addItem(TRIGGERS_OPTION_ALL, S_SHOW_ALL);
-	}
-	if(TRIGGERS_OPTION_ONLYTRUE){
-		$tr_select->additem(TRIGGERS_OPTION_ONLYTRUE, S_SHOW_ONLY_PROBLEMS);
-	}
-	if(TRIGGERS_OPTION_SHOW_ALL_WITH_UNACKNOWLEDGED && $config['event_ack_enable']){
-		$tr_select->addItem(TRIGGERS_OPTION_SHOW_ALL_WITH_UNACKNOWLEDGED, S_SHOW_ALL_WITH_UNACKNOWLEDGED);
+	$tr_select->addItem(TRIGGERS_OPTION_ALL, S_ANY);
+	$tr_select->additem(TRIGGERS_OPTION_ONLYTRUE, S_PROBLEM);
+	$filterForm->addRow(S_TRIGGERS_STATUS, $tr_select);
+
+	if($config['event_ack_enable']){
+		$cb_ack_status = new CComboBox('ack_status', $ack_status);
+		$cb_ack_status->addItem(ZBX_ACK_STS_ANY, S_ANY);
+		$cb_ack_status->additem(ZBX_ACK_STS_WITH_UNACK, S_WITH_UNACKNOWLEDGED_EVENTS);
+		$cb_ack_status->additem(ZBX_ACK_STS_WITH_LAST_UNACK, S_WITH_LAST_EVENT_UNACKNOWLEDGED);
+		$filterForm->addRow(S_ACKNOWLEDGE_STATUS, $cb_ack_status);
 	}
 
 	$ev_select = new CComboBox('show_events', $_REQUEST['show_events']);
-	if(EVENTS_OPTION_NOEVENT){
-		$ev_select->addItem(EVENTS_OPTION_NOEVENT, S_HIDE_ALL);
-	}
-	if(EVENTS_OPTION_ALL){
-		$ev_select->addItem(EVENTS_OPTION_ALL, S_SHOW_ALL.SPACE.'('.$config['event_expire'].SPACE.(($config['event_expire']>1)?S_DAYS:S_DAY).')');
-	}
-	if(EVENTS_OPTION_NOT_ACK && $config['event_ack_enable']){
+	$ev_select->addItem(EVENTS_OPTION_NOEVENT, S_HIDE_ALL);
+	$ev_select->addItem(EVENTS_OPTION_ALL, S_SHOW_ALL.SPACE.'('.$config['event_expire'].SPACE.(($config['event_expire']>1)?S_DAYS:S_DAY).')');
+	if($config['event_ack_enable']){
 		$ev_select->addItem(EVENTS_OPTION_NOT_ACK, S_SHOW_UNACKNOWLEDGED.SPACE.'('.$config['event_expire'].SPACE.(($config['event_expire']>1)?S_DAYS:S_DAY).')');
 	}
-	if(EVENTS_OPTION_ONLYTRUE_NOTACK && $config['event_ack_enable']){
-		$ev_select->addItem(EVENTS_OPTION_ONLYTRUE_NOTACK, S_SHOW_PROBLEM_UNACKNOWLEDGED.SPACE.'('.$config['event_expire'].SPACE.(($config['event_expire']>1)?S_DAYS:S_DAY).')');
-	}
-	if(EVENTS_OPTION_EVENT_LAST && $config['event_ack_enable']){
-		$ev_select->addItem(EVENTS_OPTION_EVENT_LAST,S_SHOW_LAST);
-	}
-
-	$filterForm->addRow(S_TRIGGERS, $tr_select);
 	$filterForm->addRow(S_EVENTS, $ev_select);
 
 	$severity_select = new CComboBox('show_severity', $show_severity);
-	$severity_select->addItem(-1, S_ALL_S);
-	$severity_select->addItem(TRIGGER_SEVERITY_NOT_CLASSIFIED, 	S_NOT_CLASSIFIED);
-	$severity_select->addItem(TRIGGER_SEVERITY_INFORMATION,		S_INFORMATION);
-	$severity_select->addItem(TRIGGER_SEVERITY_WARNING,			S_WARNING);
-	$severity_select->addItem(TRIGGER_SEVERITY_AVERAGE,			S_AVERAGE);
-	$severity_select->addItem(TRIGGER_SEVERITY_HIGH,			S_HIGH);
-	$severity_select->addItem(TRIGGER_SEVERITY_DISASTER,		S_DISASTER);
+	$cb_items = array(
+		-1 => S_ALL_S,
+		TRIGGER_SEVERITY_NOT_CLASSIFIED => S_NOT_CLASSIFIED,
+		TRIGGER_SEVERITY_INFORMATION => S_INFORMATION,
+		TRIGGER_SEVERITY_WARNING => S_WARNING,
+		TRIGGER_SEVERITY_AVERAGE => S_AVERAGE,
+		TRIGGER_SEVERITY_HIGH => S_HIGH,
+		TRIGGER_SEVERITY_DISASTER => S_DISASTER,
+	);
+	$severity_select->addItems($cb_items);
 	$filterForm->addRow(S_MIN_SEVERITY, $severity_select);
 
+	$action = 'javascrip: this.checked ? $("status_change_days").enable() : $("status_change_days").disable()';
+	$sts_change_days_cb = new CNumericBox('status_change_days', $_REQUEST['status_change_days'], 4);
+	if(!$_REQUEST['status_change']) $sts_change_days_cb->setAttribute('disabled', 'disabled');
+    $sts_change_days_cb->addStyle('vertical-align: middle;');
+
+	$cbd = new CCheckBox('status_change', $_REQUEST['status_change'], $action, 1);
+	$cbd->addStyle('vertical-align: middle;');
+
+	$spand = new CSpan(S_DAYS_SMALL);
+	$spand->addStyle('vertical-align: middle;');
+	$filterForm->addRow(S_AGE_LESS_THAN, array(
+		$cbd,
+		$sts_change_days_cb,
+		$spand,
+	));
+
 	$filterForm->addRow(S_SHOW_DETAILS, new CCheckBox('show_details', $_REQUEST['show_details'], null, 1));
 
-	$filterForm->addRow(S_SELECT, new CTextBox('txt_select', $_REQUEST['txt_select'], 40));
+	$filterForm->addRow(S_FILTER_BY_NAME, new CTextBox('txt_select', $_REQUEST['txt_select'], 40));
 
 	$filterForm->addItemToBottomRow(new CButton('filter_set', S_FILTER));
 	$filterForm->addItemToBottomRow(new CButton('filter_rst', S_RESET));
@@ -295,13 +254,14 @@ include_once('include/page_header.php');
 /*************** FILTER END ******************/
 
   	if($_REQUEST['fullscreen']){
-		$triggerInfo = new CTriggersInfo();
+		$triggerInfo = new CTriggersInfo($_REQUEST['groupid'], $_REQUEST['hostid']);
 		$triggerInfo->HideHeader();
 		$triggerInfo->show();
 	}
 
 	$m_form = new CForm('acknow.php');
 	$m_form->setName('tr_status');
+	$m_form->addVar('backurl', $page['file']);
 
 	$admin_links = (($USER_DETAILS['type'] == USER_TYPE_ZABBIX_ADMIN) || ($USER_DETAILS['type'] == USER_TYPE_SUPER_ADMIN));
 	$show_event_col = ($config['event_ack_enable'] && ($_REQUEST['show_events'] != EVENTS_OPTION_NOEVENT));
@@ -313,9 +273,7 @@ include_once('include/page_header.php');
 		: new CCheckBox('all_triggers', false, "checkAll('".$m_form->GetName()."','all_triggers', 'triggers');");
 
 	if($show_events != EVENTS_OPTION_NOEVENT){
-		//$whow_hide_all = new CDiv(new CImg('images/general/closed.gif'), 'pointer');
 		$whow_hide_all = new CDiv(SPACE, 'filterclosed');
-
 		$whow_hide_all->setAttribute('id', $switcherName);
 	}
 	else{
@@ -342,10 +300,9 @@ include_once('include/page_header.php');
 	$sortorder = getPageSortOrder();
 	$options = array(
 		'nodeids' => get_current_nodeid(),
-		'status' => TRIGGER_STATUS_ENABLED,
-		'filter' => 1,
-		'monitored' => 1,
-		'extendoutput' => 1,
+		'filter' => array(),
+		'active' => 1,
+		'output' => API_OUTPUT_EXTEND,
 		'skipDependent' => 1,
 		'sortfield' => $sortfield,
 		'sortorder' => $sortorder,
@@ -353,29 +310,35 @@ include_once('include/page_header.php');
 	);
 
 // Filtering
-	if(($PAGE_HOSTS['selected'] > 0) || empty($PAGE_HOSTS['hostids'])){
-		$options['hostids'] = $PAGE_HOSTS['selected'];
+	if($pageFilter->hostsSelected){
+		if($pageFilter->hostid > 0)
+			$options['hostids'] = $pageFilter->hostid;
+		else if($pageFilter->groupid > 0)
+			$options['groupids'] = $pageFilter->groupid;
 	}
-	else if(($PAGE_GROUPS['selected'] > 0) && !empty($PAGE_HOSTS['hostids'])){
-		$options['hostids'] = $PAGE_HOSTS['hostids'];
-	}
-	else if(($PAGE_GROUPS['selected'] > 0) || empty($PAGE_GROUPS['groupids'])){
-		$options['groupids'] = $PAGE_GROUPS['selected'];
+	else{
+		$options['hostids'] = array();
 	}
 
 
 	if(!zbx_empty($_REQUEST['txt_select'])){
-		$options['pattern'] = $_REQUEST['txt_select'];
+		$options['search'] = array('description' => $_REQUEST['txt_select']);
 	}
 	if($show_triggers == TRIGGERS_OPTION_ONLYTRUE){
 		$options['only_true'] = 1;
 	}
-	if($show_triggers == TRIGGERS_OPTION_SHOW_ALL_WITH_UNACKNOWLEDGED){
-		$options['with_unacknowledged_events'] = 1;
+	if($ack_status == ZBX_ACK_STS_WITH_UNACK){
+		$options['withUnacknowledgedEvents'] = 1;
+	}
+	if($ack_status == ZBX_ACK_STS_WITH_LAST_UNACK){
+		$options['withLastEventUnacknowledged'] = 1;
 	}
 	if($show_severity > -1){
 		$options['min_severity'] = $show_severity;
 	}
+	if($_REQUEST['status_change']){
+		$options['lastChangeSince'] = time() - ($_REQUEST['status_change_days'] * 86400);
+	}
 
 	$triggers = CTrigger::get($options);
 
@@ -386,53 +349,55 @@ include_once('include/page_header.php');
 	$options = array(
 		'nodeids' => get_current_nodeid(),
 		'triggerids' => zbx_objectValues($triggers, 'triggerid'),
-		'extendoutput' => 1,
-		'select_hosts' => 1,
-		'select_items' => 1,
-		'select_dependencies' => 1
+		'output' => API_OUTPUT_EXTEND,
+		'select_hosts' => array('hostid', 'host', 'maintenance_status', 'maintenance_type', 'maintenanceid'),
+		'select_items' => API_OUTPUT_EXTEND,
+		'select_dependencies' => API_OUTPUT_EXTEND
 	);
 	$triggers = CTrigger::get($options);
 	$triggers = zbx_toHash($triggers, 'triggerid');
-	
+
 	order_result($triggers, $sortfield, $sortorder);
 //---------
 
 	if($config['event_ack_enable']){
 		foreach($triggers as $tnum => $trigger){
 			$options = array(
-				'count' => 1,
+				'countOutput' => 1,
 				'triggerids' => $trigger['triggerid'],
 				'object' => EVENT_OBJECT_TRIGGER,
 				'acknowledged' => 0,
 				'value' => TRIGGER_VALUE_TRUE,
 				'nopermissions' => 1
 			);
-			$event_count = CEvent::get($options);
-
-			$triggers[$tnum]['event_count'] = $event_count['rowscount'];
+			$triggers[$tnum]['event_count'] = CEvent::get($options);
 		}
 	}
 
-	$trigger_hosts = array();
+
+	$tr_hostids = array();
 	foreach($triggers as $tnum => $trigger){
-		$trigger_hosts = array_merge($trigger_hosts, $trigger['hosts']);
 		$triggers[$tnum]['events'] = array();
+
+		//getting all host ids and names
+		foreach($trigger['hosts'] as $tr_hosts){
+			$tr_hostids[$tr_hosts['hostid']] = $tr_hosts['hostid'];
+		}
 	}
 
-	$trigger_hostids = zbx_objectValues($trigger_hosts, 'hostid');
 
-	$scripts_by_hosts = Cscript::getScriptsByHosts($trigger_hostids);
+	$scripts_by_hosts = Cscript::getScriptsByHosts($tr_hostids);
 
 	if($show_events != EVENTS_OPTION_NOEVENT){
 		$ev_options = array(
 			'nodeids' => get_current_nodeid(),
 			'triggerids' => zbx_objectValues($triggers, 'triggerid'),
 			'nopermissions' => 1,
-			'extendoutput' => 1,
-			'sortfield' => 'clock',
-			'sortorder' => ZBX_SORT_DOWN,
+			'output' => API_OUTPUT_EXTEND,
 			'time_from' => time() - ($config['event_expire']*86400),
 			'time_till' => time(),
+			'sortfield' => 'eventid',
+			'sortorder' => ZBX_SORT_DOWN,
 			//'limit' => $config['event_show_max']
 		);
 
@@ -443,13 +408,10 @@ include_once('include/page_header.php');
 				$ev_options['acknowledged'] = 0;
 				$ev_options['value'] = TRIGGER_VALUE_TRUE;
 			break;
-			case EVENTS_OPTION_ONLYTRUE_NOTACK:
-				$ev_options['acknowledged'] = 0;
-				$ev_options['value'] = TRIGGER_VALUE_TRUE;
-			break;
 		}
 
 		$events = CEvent::get($ev_options);
+		order_result($events, 'clock', ZBX_SORT_DOWN);
 
 		foreach($events as $enum => $event){
 			$triggers[$event['objectid']]['events'][] = $event;
@@ -457,18 +419,34 @@ include_once('include/page_header.php');
 	}
 
 
-
 	foreach($triggers as $tnum => $trigger){
+		
 		$trigger['desc'] = $description = expand_trigger_description($trigger['triggerid']);
 
-// Items
 		$items = array();
+
+		$used_hosts = array();
+		foreach($trigger['hosts'] as $th){
+			$used_hosts[$th['hostid']] = $th['host'];
+		}
+		$used_host_count = count($used_hosts);
+		
 		foreach($trigger['items'] as $inum => $item){
+			$item_description = item_description($item);
+
+			//if we have items from different hosts, we must prefix a host name
+			if ($used_host_count > 1) {
+				$item_description = $used_hosts[$item['hostid']].':'.$item_description;
+			}
+
 			$items[$inum]['itemid'] = $item['itemid'];
+			$items[$inum]['value_type'] = $item['value_type']; //ZBX-3059: So it would be possible to show different caption for history for chars and numbers (KB)
 			$items[$inum]['action'] = str_in_array($item['value_type'], array(ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_UINT64)) ? 'showgraph' : 'showvalues';
-			$items[$inum]['description'] = item_description($item);
+			$items[$inum]['description'] = $item_description;
 		}
 		$trigger['items'] = $items;
+
+
 //----
 
 		$description = new CSpan($description, 'link_menu');
@@ -478,7 +456,7 @@ include_once('include/page_header.php');
 
 		$menu_trigger_conf = 'null';
 		if($admin_links){
-			$menu_trigger_conf = "['".S_CONFIGURATION_OF_TRIGGERS."',\"javascript: 
+			$menu_trigger_conf = "['".S_CONFIGURATION_OF_TRIGGERS."',\"javascript:
 				redirect('triggers.php?form=update&triggerid=".$trigger['triggerid'].'&switch_node='.id2nodeid($trigger['triggerid'])."')\",
 				null, {'outer' : ['pum_o_item'],'inner' : ['pum_i_item']}]";
 		}
@@ -493,6 +471,8 @@ include_once('include/page_header.php');
 				"', 'lastchange': '".$trigger['lastchange']."'}, ".$menu_trigger_conf.", ".$menu_trigger_url."),".
 			zbx_jsvalue($items, true).");"
 		);
+
+		
 // }}} trigger description js menu
 
 		if($_REQUEST['show_details']){
@@ -567,6 +547,8 @@ include_once('include/page_header.php');
 
 			$menus = rtrim($menus,',');
 			$menus = 'show_popup_menu(event,['.$menus.'],180);';
+			
+			
 
 			$maint_span = null;
 			if($trigger_host['maintenance_status']){
@@ -574,19 +556,28 @@ include_once('include/page_header.php');
 				$text = ' ['.$text.']';
 				$maint_span = new CSpan($text, 'orange pointer');
 
-				$maintenance = CMaintenance::get(array('maintenanceids' => $trigger_host['maintenanceid'], 'extendoutput' => 1));
-				$maintenance = reset($maintenance);
+				$maintenanceOptions = array(
+					'maintenanceids' => $trigger_host['maintenanceid'],
+					'output' => API_OUTPUT_EXTEND
+				);
+				$maintenances = CMaintenance::get($maintenanceOptions);
+				$maintenance = reset($maintenances);
+
 				$maint_hint = new CSpan($maintenance['name'].($maintenance['description']=='' ? '' : ': '.$maintenance['description']));
 
 				$maint_span->setHint($maint_hint);
 			}
 
+			
+
 
 			$hosts_span = new CSpan($trigger_host['host'], 'link_menu');
 			$hosts_span->setAttribute('onclick','javascript: '.$menus);
 			$hosts_list[] = $hosts_span;
 			$hosts_list[] = $maint_span;
 			$hosts_list[] = ', ';
+
+			
 		}
 
 		array_pop($hosts_list);
@@ -594,17 +585,18 @@ include_once('include/page_header.php');
 		$host->addStyle('white-space: normal;');
 // }}} host JS menu
 
+		
 
 		$status = new CSpan(trigger_value2str($trigger['value']), get_trigger_value_style($trigger['value']));
 		if((time() - $trigger['lastchange']) < TRIGGER_BLINK_PERIOD){
 			$status->setAttribute('name', 'blink');
 		}
 		$lastchange = new CLink(zbx_date2str(S_DATE_FORMAT_YMDHMS, $trigger['lastchange']), 'events.php?triggerid='.$trigger['triggerid']);
-		//.'&stime='.date('YmdHi', $trigger['lastchange']
+		//.'&stime='.date('YmdHis', $trigger['lastchange']
 
 		if($config['event_ack_enable']){
 			if($trigger['event_count']){
-				$to_ack = new CCol(array(new CLink(S_ACKNOWLEDGE, 'acknow.php?triggers[]='.$trigger['triggerid'], 'on'), ' ('.$trigger['event_count'].')'));
+				$to_ack = new CCol(array(new CLink(S_ACKNOWLEDGE, 'acknow.php?triggers[]='.$trigger['triggerid'].'&backurl='.$page['file'], 'on'), ' ('.$trigger['event_count'].')'));
 			}
 			else{
 				$to_ack = new CCol(S_ACKNOWLEDGED, 'off');
@@ -660,10 +652,10 @@ include_once('include/page_header.php');
 						if($row_event['acknowledged'] == 1){
 							$acks_cnt = DBfetch(DBselect('SELECT COUNT(*) as cnt FROM acknowledges WHERE eventid='.$row_event['eventid']));
 							$ack = array(new CSpan(S_YES, 'off'),SPACE.'('.$acks_cnt['cnt'].SPACE,
-								new CLink(S_SHOW,'acknow.php?eventid='.$row_event['eventid']),')');
+								new CLink(S_SHOW,'acknow.php?eventid='.$row_event['eventid'].'&backurl='.$page['file']),')');
 						}
 						else{
-							$ack = new CLink(S_NOT_ACKNOWLEDGED, 'acknow.php?eventid='.$row_event['eventid'], 'on');
+							$ack = new CLink(S_NOT_ACKNOWLEDGED, 'acknow.php?eventid='.$row_event['eventid'].'&backurl='.$page['file'], 'on');
 						}
 					}
 					else{
@@ -717,13 +709,6 @@ include_once('include/page_header.php');
 		$goButton = new CButton('goButton', S_GO.' (0)');
 		$goButton->setAttribute('id', 'goButton');
 
-		$jsLocale = array(
-			'S_CLOSE',
-			'S_NO_ELEMENTS_SELECTED'
-		);
-
-		zbx_addJSLocale($jsLocale);
-
 		$show_event_col ? zbx_add_post_js('chkbxRange.pageGoName = "events";') : zbx_add_post_js('chkbxRange.pageGoName = "triggers";');
 
 		$footer = get_table_header(array($goBox, $goButton));
@@ -746,4 +731,4 @@ include_once('include/page_header.php');
 
 include_once('include/page_footer.php');
 
-?>
\ No newline at end of file
+?>
